# ICS to SMS


## Installing

Just `pip install ics-to-sms`, in a venv.


## Using from command line

It can be used from command line, I like
[passwordstore](https://www.passwordstore.org/) so I'd use:

    python ics_to_sms.py --ics-url 'https://framagenda.org/.../?export' --ics-username mdk --ics-password "$(pass framagenda)" --free-user "$(pass free/sms-api-id)" --free-api-key "$(pass free/sms-api-key)"


## Using with a config file

It can also be configured using a `toml` file like:

```toml
ics_url = "https://..."
ics_username = "mdk"
ics_password = "redacted for my privacy"
free_user = "..."
free_api_key = "..."
```

then ran using:

    python ics_to_sms.py --config config.toml


## Deploying on a server

I use an Ansible playbook to deploy this to my server, feel free to copy-paste:

https://git.afpy.org/mdk/infra/src/branch/main/ics_to_sms.yml
